@@ -1139,7 +1139,9 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
         NSUInteger folderIndex;
         @synchronized(_foundMedia) {
             folderIndex = [_foundMedia indexOfObject:_folderObject];
-            mediaObject = _foundMedia[folderIndex];
+            if (folderIndex != NSNotFound) {
+                mediaObject = _foundMedia[folderIndex];
+            }
         }
 
         //item got dragged onto item
@@ -1359,9 +1361,8 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
 - (IBAction)backToAllItems:(id)sender
 {
     _inFolder = NO;
-    UIBarButtonItem *createFolderItem = [[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemOrganize target:self action:@selector(createFolder)];
     NSMutableArray *toolbarItems = [self.toolbarItems mutableCopy];
-    toolbarItems[2] = createFolderItem;
+    toolbarItems[2] = _createFolderBarButtonItem;
     self.toolbarItems = toolbarItems;
     [self setLibraryMode:_previousLibraryMode];
     if (!self.isEditing) {
@@ -1386,11 +1387,21 @@ static NSString *kUsingTableViewToShowData = @"UsingTableViewToShowData";
     NSArray *indexPaths = [self usingTableViewToShowData] ? [self.tableView indexPathsForSelectedRows] : [self.collectionView indexPathsForSelectedItems];
 
     if ((!indexPaths || [indexPaths count] == 0) && !_deleteFromTableView) {
-        UIAlertController *invalidSelection = [UIAlertController alertControllerWithTitle:NSLocalizedString(@"DELETE_INVALID_TITLE", nil) message:NSLocalizedString(@"DELETE_INVALID_MESSAGE", nil) preferredStyle:UIAlertControllerStyleAlert];
-        UIAlertAction *doneAction = [UIAlertAction actionWithTitle:NSLocalizedString(@"BUTTON_OK", nil) style:UIAlertActionStyleDefault handler:nil];
+        if ([UIAlertController class]) {
+            UIAlertController *invalidSelection = [UIAlertController alertControllerWithTitle:NSLocalizedString(@"DELETE_INVALID_TITLE", nil) message:NSLocalizedString(@"DELETE_INVALID_MESSAGE", nil) preferredStyle:UIAlertControllerStyleAlert];
+            UIAlertAction *doneAction = [UIAlertAction actionWithTitle:NSLocalizedString(@"BUTTON_OK", nil) style:UIAlertActionStyleDefault handler:nil];
 
-        [invalidSelection addAction:doneAction];
-        [self presentViewController:invalidSelection animated:YES completion:nil];
+            [invalidSelection addAction:doneAction];
+            [self presentViewController:invalidSelection animated:YES completion:nil];
+        } else {
+            //TODO remove when we drop iOS7
+            VLCAlertView *alert = [[VLCAlertView alloc] initWithTitle:NSLocalizedString(@"DELETE_INVALID_TITLE", nil)
+                                                              message:NSLocalizedString(@"DELETE_INVALID_MESSAGE", nil)
+                                                    cancelButtonTitle:NSLocalizedString(@"BUTTON_OK", nil)
+                                                    otherButtonTitles:nil];
+            alert.completion = nil;
+            [alert show];
+        }
     } else {
         if ([UIAlertController class]) {
             UIAlertController *alert = [UIAlertController alertControllerWithTitle:NSLocalizedString(@"DELETE_TITLE", nil) message:nil preferredStyle:UIAlertControllerStyleActionSheet];
